@@ -1,6 +1,7 @@
 
 from collections import OrderedDict
-from .nonp import strip_comments, dumps, loads
+from json_tricks.test_class import MyTestCls, CustomEncodeCls
+from json_tricks.nonp import strip_comments, dumps, loads
 
 
 nonpdata = {
@@ -55,12 +56,37 @@ ordered_map = OrderedDict((
 
 
 def test_order():
-	json = dumps(ordered_map, preserve_order=True)
+	json = dumps(ordered_map)
 	data2 = loads(json, preserve_order=True)
 	assert tuple(ordered_map.keys()) == tuple(data2.keys())
 	reverse = OrderedDict(reversed(tuple(ordered_map.items())))
-	json = dumps(reverse, preserve_order=True)
+	json = dumps(reverse)
 	data3 = loads(json, preserve_order=True)
 	assert tuple(reverse.keys()) == tuple(data3.keys())
 
 
+cls_instance = MyTestCls(s='ub', dct={'7': 7})
+cls_instance_custom = CustomEncodeCls()
+
+
+def test_cls_instance_default():
+	json = dumps(cls_instance)
+	print(dumps(cls_instance, indent=4))
+	back = loads(json)
+	assert (cls_instance.s == back.s)
+	assert (cls_instance.dct == dict(back.dct))
+
+
+def test_cls_instance_custom():
+	json = dumps(cls_instance_custom)
+	back = loads(json)
+	assert (cls_instance_custom.relevant == back.relevant)
+	assert (cls_instance_custom.irrelevant == 37)
+	assert (back.irrelevant == 12)
+
+
+def test_cls_instance_local():
+	json = '{"__instance_type__": [null, "CustomEncodeCls"], "attributes": {"relevant": 137}}'
+	loads(json, cls_lookup_map=globals())
+
+
